<?php

// phpcs:disable
use CRM_Noteaccess_ExtensionUtil as E;
// phpcs:enable

class CRM_Noteaccess_Form_Note {

  /**
   * @see noteaccess_civicrm_buildForm()
   */
  public static function buildForm(&$form): void {
    $note_id = $form->getVar('_id');

    if ($note_id) {
      if (!CRM_Noteaccess_Utils::userCanEditNote($note_id)) {
        throw new Exception(E::ts('Access denied'));
      }
    }

    // More filtering done by Civi/Api4/Event/Subscriber/NoteaccessSubscriber.php
    $form->addAutocomplete("noteaccess_contact_id", E::ts('Contacts'), [
      'select' => ['multiple' => true, 'minimumInputLength' => 0],
    ]);

    // Find the option_value from this extension, so that we can apply JS on the tpl
    $optionValue = \Civi\Api4\OptionValue::get(TRUE)
      ->addWhere('option_group_id:name', '=', 'note_privacy')
      ->addWhere('name', '=', 'specific_contacts')
      ->execute()
      ->first();

    if ($optionValue) {
      Civi::resources()->addVars('noteaccess', ['oid' => $optionValue['value']]);
    }
    else {
      Civi::resources()->addScript("console.log('noteaccess extension: The specific_contacts option value for the privacy levels is missing');");
    }

    // Add our template to render the field
    CRM_Core_Region::instance('form-bottom')->add([
      'template' => 'CRM/Noteaccess/Form/Note.tpl',
    ]);

    // Set default values

    if ($note_id) {
      $old = (array) \Civi\Api4\NoteAccess::get(FALSE)
        ->addSelect('contact_id')
        ->addWhere('note_id', '=', $note_id)
        ->execute()
        ->indexBy('contact_id');

      $form->setDefaults([
        'noteaccess_contact_id' => implode(',', array_keys($old)),
      ]);
    }
  }

  /**
   * @see noteaccess_civicrm_postProcess()
   */
  public static function postProcess(&$form): void {
    $values = $form->exportValues();
    $contact_ids = explode(',', $values['noteaccess_contact_id']);

    $note_id = $form->getVar('_id');

    $old = \Civi\Api4\NoteAccess::get(FALSE)
      ->addSelect('contact_id')
      ->addWhere('note_id', '=', $note_id)
      ->execute()
      ->indexBy('contact_id');

    foreach ($contact_ids as $cid) {
      if (!$cid) {
        continue;
      }

      // Check if they already have access
      if (!empty($old[$cid])) {
        continue;
      }

      \Civi\Api4\NoteAccess::create(FALSE)
        ->addValue('note_id', $note_id)
        ->addValue('contact_id', $cid)
        ->execute();
    }

    // Cleanup those that were removed
    foreach ($old as $cid => $discard) {
      if (!in_array($cid, $contact_ids)) {
        \Civi\Api4\NoteAccess::delete(FALSE)
          ->addWhere('note_id', '=', $note_id)
          ->addWhere('contact_id', '=', $cid)
          ->execute();
      }
    }
  }

}
