<?php

// phpcs:disable
use CRM_Noteaccess_ExtensionUtil as E;
// phpcs:enable

class CRM_Noteaccess_Page_Note {

  /**
   * @see noteaccess_civicrm_pageRun().
   */
  public static function pageRun(&$page) {
    // If a note is restricted, only the author (or users with 'view all notes') can delete it
    if ($page->_action & CRM_Core_Action::DELETE) {
      $note_id = $page->getVar('_id');
      if (!CRM_Noteaccess_Utils::userCanEditNote($note_id)) {
        throw new Exception(E::ts('Access denied'));
      }
    }
    self::showWarningOnContactRecord($page);
  }

  private static function showWarningOnContactRecord(&$page) {
    // This same page is used for displaying the note, but then it has an _id
    // and we do not want to display the warning on the note itself
    // We also ignore "ADD", when the user is adding a comment
    if ($page->getVar('_id') || $page->getVar('_action') == CRM_Core_Action::ADD) {
      return;
    }

    // Check if there are hidden notes
    $hidden_notes = [];
    $contact_id = $page->_contactId;

    $notes = \Civi\Api4\Note::get(FALSE)
      ->addSelect('id', 'subject', 'privacy', 'contact_id', 'note_date')
      ->addWhere('entity_table', '=', 'civicrm_contact')
      ->addWhere('entity_id', '=', $contact_id)
      ->execute();

    foreach ($notes as $note) {
      if (CRM_Core_BAO_Note::getNotePrivacyHidden($note['id'])) {
        $note['display_name'] = CRM_Contact_BAO_Contact::displayName($note['contact_id']);
        // @todo Lazy date-only formatting
        $note['note_date'] = substr($note['note_date'], 0, 10);
        $hidden_notes[] = $note;
      }
    }

    // Display a warning to the user
    $x = count($hidden_notes);
    $page->assign('noteaccess_hidden_notes_count', $x);
    $page->assign('noteaccess_hidden_notes', $hidden_notes);

    CRM_Core_Region::instance('page-footer')->add([
      'template' => 'CRM/Noteaccess/Page/Note.tpl'
    ]);
  }

}
