<?php

class CRM_Noteaccess_Utils {

  /**
   *
   */
  public static function userCanViewNote($note_id, $note = NULL) {
    if (!$note) {
      $note = \Civi\Api4\Note::get(FALSE)
        ->addSelect('id', 'privacy', 'contact_id')
        ->addWhere('id', '=', $note_id)
        ->execute()
        ->single();
    }

    return !CRM_Core_BAO_Note::getNotePrivacyHidden($note);
  }

  /**
   * Returns true if the Logged-in-contact can edit the note.
   *
   * Normally CiviCRM allows anyone with edit permission to the contact to edit/delete notes.
   * We only allow the note author or contacts with 'view all notes' to delete notes.
   */
  public static function userCanEditNote($note_id) {
    // Check if they can view all notes
    if (CRM_Core_Permission::check('view all notes')) {
      return TRUE;
    }

    // Check if they are the note author
    $user_id = CRM_Core_Session::getLoggedInContactID();

    $note = \Civi\Api4\Note::get(FALSE)
      ->addSelect('id', 'privacy', 'contact_id')
      ->addWhere('id', '=', $note_id)
      ->execute()
      ->single();

    // Note author can always edit
    if ($note['contact_id'] == $user_id) {
      return TRUE;
    }

    // Note edit is restricted to author
    if (\Civi::settings()->get('noteaccess_restrict_edit')) {
      return FALSE;
    }

    return self::userCanViewNote($note_id, $note);
  }

}
