<?php

namespace Civi\Api4\Service\Autocomplete;

use Civi\Core\Service\AutoService;
use Civi\Core\Event\GenericHookEvent;
use Civi\Core\HookInterface;

/**
 * @service
 * @internal
 */
class NoteaccessContactAutocompleteProvider extends AutoService implements HookInterface {

  /**
   * Provides filtering rules to list only Contacts with a UF record
   *
   * @param \Civi\Core\Event\GenericHookEvent $e
   */
  public function on_civi_search_autocompleteDefault(GenericHookEvent $event): void {
    if (!is_array($event->savedSearch) || $event->savedSearch['api_entity'] !== 'Contact') {
      return;
    }

    // FIXME In 5.64, replace by $event->formName/fieldName
    // https://github.com/civicrm/civicrm-core/commit/4752454a6254a5f18c406fd522b31ac476eef18f#diff-9271ad537dffcf43d5ddb5b936b6f37e37ae42a8c7e3f2d4e4be8c3e3ac2bcf7R128-R129
    $params = json_decode(\CRM_Utils_Request::retrieveValue('params', 'String'), 1);

    if ($params['formName'] === 'qf:CRM_Note_Form_Note' && $params['fieldName'] === 'noteaccess_contact_id') {
      $event->savedSearch['api_params'] = [
        'version' => 4,
        'select' => [
          'id',
          'display_name',
          'contact_type',
        ],
        'orderBy' => [],
        'where' => [],
        'groupBy' => [],
        'join' => [
          [
            'UFMatch AS uf_match',
            'INNER',
            ['uf_match.contact_id', '=', 'id'],
          ],
        ],
        'having' => [],
      ];
    }
  }

}
